summaryrefslogtreecommitdiff
path: root/framework/TComponent.php
diff options
context:
space:
mode:
authorctrlaltca@gmail.com <>2011-06-20 11:00:50 +0000
committerctrlaltca@gmail.com <>2011-06-20 11:00:50 +0000
commit6dca6e1b868f5456f3151c002113705405099530 (patch)
treeb6bcf9bc23fa11bf20a4e30751108b1f6fd75efe /framework/TComponent.php
parent656c339879a071f2f875831281ed833b876e4361 (diff)
fixed 3 obvious bugs
Diffstat (limited to 'framework/TComponent.php')
-rw-r--r--framework/TComponent.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/TComponent.php b/framework/TComponent.php
index ab04c10f..ece83636 100644
--- a/framework/TComponent.php
+++ b/framework/TComponent.php
@@ -509,13 +509,13 @@ class TComponent
* by calling its {@link IBehavior::attach} method.
* @param string the behavior's name. It should uniquely identify this behavior.
* @param mixed the behavior configuration. This is passed as the first
* parameter to {@link YiiBase::createComponent} to create the behavior object.
* @return IBehavior the behavior object
*/
public function attachBehavior($name,$behavior)
{
if(!($behavior instanceof IBehavior))
- $behavior=Yii::createComponent($behavior);
+ $behavior=Prado::createComponent($behavior);
$behavior->setEnabled(true);
$behavior->attach($this);
return $this->_m[$name]=$behavior;
@@ -509,13 +509,13 @@ class TComponent
* @param string the behavior's name. It should uniquely identify this behavior.
* @param mixed the behavior configuration. This is passed as the first
- * parameter to {@link YiiBase::createComponent} to create the behavior object.
+ * parameter to {@link PradoBase::createComponent} to create the behavior object.
* @return IBehavior the behavior object
*/